@@ -148,8 +148,15 @@ class vnlog:
             # Not comment, not empty line, but no legend yet. Barf
             raise Exception("Got dataline before legend")
 
+        # string trailing comments
+        i = l.find('#')
+        if i >= 0:
+            l = l[:i]
+
         # strip leading, trailing whitespace
         l = l.strip()
+        if len(l) == 0:
+            return True
 
         self._values = [ None if x == '-' else x for x in l.split()]
         if len(self._values) != len(self._keys):
@@ -226,6 +233,18 @@ def _slurp(f):
     '''
     import numpy as np
 
+
+    # Stripped down numpysane.atleast_dims(). I don't want to introduce that
+    # dependency
+    def atleast_dims(x, d):
+        if d >= 0: raise Exception("Requires d<0")
+        need_ndim = -d
+        if x.ndim >= need_ndim:
+            return x
+        num_new_axes = need_ndim-x.ndim
+        return x[ (np.newaxis,)*(num_new_axes) ]
+
+
     parser = vnlog()
 
     for l in f:
@@ -238,7 +257,10 @@ def _slurp(f):
     for i in range(len(keys)):
         dict_key_index[keys[i]] = i
 
-    return np.loadtxt(f),keys,dict_key_index
+    return                               \
+        atleast_dims(np.loadtxt(f), -2), \
+        keys,                            \
+        dict_key_index
 
 
 def slurp(f):
